.. py:function:: sf_hyperg_2F1_renorm_e(a, b, c, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_2F1_renorm_e`
    c code signature: int gsl_sf_hyperg_2F1_renorm_e(const double a, const double b, const double c, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double c: positional argument 2
    :param double x: positional argument 3
    :param int ret: positional argument 4
    :param double result.val: positional argument 5
    :param double result.err: positional argument 6
    :rtype:  tuple(:param int ret: positional argument 4, :param double result.val: positional argument 5, :param double result.err: positional argument 6) 
    :return: result 

.. py:function:: sf_hyperg_U_int(m, n, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_U_int`
    c code signature: double gsl_sf_hyperg_U_int(const int m, const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_d__Rd__O`
    
    :param int m: positional argument 0
    :param int n: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_hyperg_2F0_e(a, b, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_2F0_e`
    c code signature: int gsl_sf_hyperg_2F0_e(const double a, const double b, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_hyperg_1F1_e(a, b, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_1F1_e`
    c code signature: int gsl_sf_hyperg_1F1_e(const double a, const double b, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_hyperg_2F1_conj_renorm(aR, aI, c, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_2F1_conj_renorm`
    c code signature: double gsl_sf_hyperg_2F1_conj_renorm( double aR,  double aI,  double c,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rd__O`
    
    :param double aR: positional argument 0
    :param double aI: positional argument 1
    :param double c: positional argument 2
    :param double x: positional argument 3
    :param double ret: positional argument 4
    :rtype:  double 
    :return: result 

.. py:function:: sf_hyperg_2F1_renorm(a, b, c, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_2F1_renorm`
    c code signature: double gsl_sf_hyperg_2F1_renorm( double a,  double b,  double c,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rd__O`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double c: positional argument 2
    :param double x: positional argument 3
    :param double ret: positional argument 4
    :rtype:  double 
    :return: result 

.. py:function:: sf_hyperg_U_int_e(m, n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_U_int_e`
    c code signature: int gsl_sf_hyperg_U_int_e(const int m, const int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_d__Rl__Ord`
    
    :param int m: positional argument 0
    :param int n: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_hyperg_U_e10_e(a, b, x [, ret, result])

    Wrapper for :c:func:`gsl_sf_hyperg_U_e10_e`
    c code signature: int gsl_sf_hyperg_U_e10_e(const double a, const double b, const double x, gsl_sf_result_e10* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d__Rl__Oerd`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param gsl_sf_result_e10 result: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 3, :param gsl_sf_result_e10 result: positional argument 4) 
    :return: result 

.. py:function:: sf_hyperg_0F1_e(c, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_0F1_e`
    c code signature: int gsl_sf_hyperg_0F1_e( double c,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double c: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_hyperg_U_int_e10_e(m, n, x [, ret, result])

    Wrapper for :c:func:`gsl_sf_hyperg_U_int_e10_e`
    c code signature: int gsl_sf_hyperg_U_int_e10_e(const int m, const int n, const double x, gsl_sf_result_e10* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_d__Rl__Oerd`
    
    :param int m: positional argument 0
    :param int n: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param gsl_sf_result_e10 result: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 3, :param gsl_sf_result_e10 result: positional argument 4) 
    :return: result 

.. py:function:: sf_hyperg_U_e(a, b, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_U_e`
    c code signature: int gsl_sf_hyperg_U_e(const double a, const double b, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_hyperg_2F1_conj(aR, aI, c, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_2F1_conj`
    c code signature: double gsl_sf_hyperg_2F1_conj( double aR,  double aI,  double c,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rd__O`
    
    :param double aR: positional argument 0
    :param double aI: positional argument 1
    :param double c: positional argument 2
    :param double x: positional argument 3
    :param double ret: positional argument 4
    :rtype:  double 
    :return: result 

.. py:function:: sf_hyperg_2F1_e(a, b, c, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_2F1_e`
    c code signature: int gsl_sf_hyperg_2F1_e( double a,  double b, const double c, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double c: positional argument 2
    :param double x: positional argument 3
    :param int ret: positional argument 4
    :param double result.val: positional argument 5
    :param double result.err: positional argument 6
    :rtype:  tuple(:param int ret: positional argument 4, :param double result.val: positional argument 5, :param double result.err: positional argument 6) 
    :return: result 

.. py:function:: sf_hyperg_2F1_conj_e(aR, aI, c, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_2F1_conj_e`
    c code signature: int gsl_sf_hyperg_2F1_conj_e(const double aR, const double aI, const double c, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rl__Ord`
    
    :param double aR: positional argument 0
    :param double aI: positional argument 1
    :param double c: positional argument 2
    :param double x: positional argument 3
    :param int ret: positional argument 4
    :param double result.val: positional argument 5
    :param double result.err: positional argument 6
    :rtype:  tuple(:param int ret: positional argument 4, :param double result.val: positional argument 5, :param double result.err: positional argument 6) 
    :return: result 

.. py:function:: sf_hyperg_2F1(a, b, c, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_2F1`
    c code signature: double gsl_sf_hyperg_2F1( double a,  double b,  double c,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rd__O`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double c: positional argument 2
    :param double x: positional argument 3
    :param double ret: positional argument 4
    :rtype:  double 
    :return: result 

.. py:function:: sf_hyperg_0F1(c, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_0F1`
    c code signature: double gsl_sf_hyperg_0F1(const double c, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double c: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_hyperg_U(a, b, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_U`
    c code signature: double gsl_sf_hyperg_U(const double a, const double b, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d__Rd__O`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_hyperg_2F1_conj_renorm_e(aR, aI, c, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_2F1_conj_renorm_e`
    c code signature: int gsl_sf_hyperg_2F1_conj_renorm_e(const double aR, const double aI, const double c, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rl__Ord`
    
    :param double aR: positional argument 0
    :param double aI: positional argument 1
    :param double c: positional argument 2
    :param double x: positional argument 3
    :param int ret: positional argument 4
    :param double result.val: positional argument 5
    :param double result.err: positional argument 6
    :rtype:  tuple(:param int ret: positional argument 4, :param double result.val: positional argument 5, :param double result.err: positional argument 6) 
    :return: result 

.. py:function:: sf_hyperg_1F1_int(m, n, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_1F1_int`
    c code signature: double gsl_sf_hyperg_1F1_int(const int m, const int n,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_d__Rd__O`
    
    :param int m: positional argument 0
    :param int n: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_hyperg_1F1_int_e(m, n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hyperg_1F1_int_e`
    c code signature: int gsl_sf_hyperg_1F1_int_e(const int m, const int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_d__Rl__Ord`
    
    :param int m: positional argument 0
    :param int n: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_hyperg_1F1(a, b, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_1F1`
    c code signature: double gsl_sf_hyperg_1F1( double a,  double b,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d__Rd__O`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_hyperg_2F0(a, b, x [, ret])

    Wrapper for :c:func:`gsl_sf_hyperg_2F0`
    c code signature: double gsl_sf_hyperg_2F0(const double a, const double b, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d__Rd__O`
    
    :param double a: positional argument 0
    :param double b: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

